pub trait EncoderInput {
// Required methods
fn pitch(&self) -> u32;
fn handle(&mut self) -> *mut c_void;
}Expand description
If a type implements this trait it means it is a valid input buffer for the encoding API.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".