EncoderOutput

Trait EncoderOutput 

pub trait EncoderOutput {
    // Required method
    fn handle(&mut self) -> *mut c_void;
}
If a type implements this trait it means it is a valid output buffer for the encoding API.

Required Methods

fn handle(&mut self) -> *mut c_void

Get the handle of the output resource.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors